Invocation of sphinx-build — flask-peewee v0.1.0 documentation

### Navigation

- index
- modules |
- flask-peewee v0.1.0 documentation »

# Invocation of sphinx-build

The sphinx-build script builds a Sphinx documentation set. It is called like this:

    $ sphinx-build [options] sourcedir builddir [filenames]

where sourcedir is the source directory, and builddir is the directory in which you want to place the built documentation. Most of the time, you don’t need to specify any filenames.

The sphinx-build script has several options:

`-b` `buildername`

  The most important option: it selects a builder. The most common builders are:

  html
    Build HTML pages. This is the default builder.
  dirhtml
    Build HTML pages, but with a single directory per document. Makes for prettier URLs (no `.html`) if served from a webserver.
  singlehtml
    Build a single HTML with the whole content.
  htmlhelp, qthelp, devhelp, epub
    Build HTML files with additional information for building a documentation collection in one of these formats.
  latex
    Build LaTeX sources that can be compiled to a PDF document using pdflatex.
  man
    Build manual pages in groff format for UNIX systems.
  text
    Build plain text files.
  doctest
    Run all doctests in the documentation, if the `doctest` extension is enabled.
  linkcheck
    Check the integrity of all external links.

  See Available builders for a list of all builders shipped with Sphinx. Extensions can add their own builders.

`-a```

  If given, always write all output files. The default is to only write output files for new and changed source files. (This may not apply to all builders.)

`-E```

  Don’t use a saved environment (the structure caching all cross-references), but rebuild it completely. The default is to only read and parse source files that are new or have changed since the last run.

`-t` `tag`

  Define the tag tag. This is relevant for `only` directives that only include their content if this tag is set.

  New in version 0.6.

`-d` `path`

  Since Sphinx has to read and parse all source files before it can write an output file, the parsed source files are cached as “doctree pickles”. Normally, these files are put in a directory called `.doctrees` under the build directory; with this option you can select a different cache directory (the doctrees can be shared between all builders).

`-c` `path`

  Don’t look for the `conf.py` in the source directory, but use the given configuration directory instead. Note that various other files and paths given by configuration values are expected to be relative to the configuration directory, so they will have to be present at this location too.

  New in version 0.3.

`-C```

  Don’t look for a configuration file; only take options via the `-D` option.

  New in version 0.5.

`-D` `setting=value`

  Override a configuration value set in the `conf.py` file. The value must be a string or dictionary value. For the latter, supply the setting name and key like this: `-D latex_elements.docclass=scrartcl`. For boolean values, use `0` or `1` as the value.

  Changed in version 0.6: The value can now be a dictionary value.

`-A` `name=value`

  Make the name assigned to value in the HTML templates.

  New in version 0.5.

`-n```

  Run in nit-picky mode. Currently, this generates warnings for all missing references.

`-N```

  Do not emit colored output. (On Windows, colored output is disabled in any case.)

`-q```

  Do not output anything on standard output, only write warnings and errors to standard error.

`-Q```

  Do not output anything on standard output, also suppress warnings. Only errors are written to standard error.

`-w` `file`

  Write warnings (and errors) to the given file, in addition to standard error.

`-W```

  Turn warnings into errors. This means that the build stops at the first warning and `sphinx-build` exits with exit status 1.

`-P```

  (Useful for debugging only.) Run the Python debugger, `pdb`, if an unhandled exception occurs while building.

You can also give one or more filenames on the command line after the source and build directories. Sphinx will then try to build only these output files (and their dependencies).

## Makefile options

The `Makefile` and `make.bat` files created by sphinx-quickstart usually run sphinx-build only with the -b and -d options. However, they support the following variables to customize behavior:

`PAPER`

  The value for :confval:`latex_paper_size`.

`SPHINXBUILD`

  The command to use instead of `sphinx-build`.

`BUILDDIR`

  The build directory to use instead of the one chosen in sphinx-quickstart.

`SPHINXOPTS`

  Additional options for sphinx-build.

### Navigation

- index
- modules |
- flask-peewee v0.1.0 documentation »